@@ -7,7 +7,7 @@ from typing import Any, Dict, Generic, Iterable, List, Optional, Set, Tuple, Typ
 
 from rics._internal_support.types import PathLikeType
 from rics.mapping import DirectionalMapping, Mapper
-from rics.mapping.exceptions import MappingError, UserMappingError
+from rics.mapping.exceptions import MappingError, MappingWarning, UserMappingError
 from rics.performance import format_perf_counter
 from rics.translation import factory
 from rics.translation.dio import DataStructureIO, resolve_io
@@ -29,19 +29,30 @@ from rics.translation.types import (
     Translatable,
 )
 from rics.utility.collections.dicts import InheritedKeysDict, MakeType
+from rics.utility.collections.misc import as_list
 from rics.utility.misc import tname
 
-_NAME_ATTRIBUTES = ("name", "names", "columns", "keys")
+_NAME_ATTRIBUTES = ("name", "columns", "keys")
 
 LOGGER = logging.getLogger(__package__).getChild("Translator")
 
+FetcherTypes = Union[
+    Fetcher[SourceType, IdType],
+    TranslationMap[NameType, SourceType, IdType],
+    SourcePlaceholderTranslations[SourceType],
+    Dict[SourceType, PlaceholderTranslations.MakeTypes],
+]
+
 
 class Translator(Generic[Translatable, NameType, SourceType, IdType]):
     """Translate IDs to human-readable labels.
 
+    The recommended way of initializing ``Translator`` instances is the :meth:`from_config` method. For configuration
+    file details, please refer to the :ref:`translator-config` page.
+
     The `Translator` is the main entry point for all translation tasks. Simplified translation process steps:
 
-        1. The :attr:`map_to_sources` method performs name-to-source mapping (see :class:`.DirectionalMapping`).
+        1. The :attr:`map` method performs name-to-source mapping (see :class:`.DirectionalMapping`).
         2. The :attr:`fetch` method extracts IDs to translate and retrieves data (see :class:`.TranslationMap`).
         3. Finally, the :attr:`translate` method applies the translations and returns to the caller.
 
@@ -50,11 +61,14 @@ class Translator(Generic[Translatable, NameType, SourceType, IdType]):
         fmt: String :class:`.Format` specification for translations.
         mapper: A :class:`.Mapper` instance for binding names to sources.
         default_fmt: Alternative :class:`.Format` to use instead of `fmt` for fallback translation of unknown IDs.
-        default_translations: Shared and/or source-specific default placeholder values for unknown IDs. See
+        default_fmt_placeholders: Shared and/or source-specific default placeholder values for unknown IDs. See
             :meth:`.InheritedKeysDict.make` for details.
+        allow_name_inheritance: If ``True``, enable name resolution fallback to the parent `translatable` when
+            translating with the ``attribute``-option. Allows nameless ``pandas.Index`` instances to inherit the name of
+            a ``pandas.Series``.
 
     Notes:
-        Untranslatable IDs will be ``None`` by default if neither `default_fmt` nor `default_translations` is given.
+        Untranslatable IDs will be ``None`` by default if neither `default_fmt` nor `default_fmt_placeholders` is given.
         Adding the `maximal_untranslated_fraction` option to :meth:`translate` will raise an exceptions if too many IDs
         are left untranslated. Note however that this verifiction step may be expensive.
 
@@ -92,75 +106,101 @@ class Translator(Generic[Translatable, NameType, SourceType, IdType]):
 
         Handling unknown IDs.
 
-    >>> default_translations = dict(
-    ...     default={'is_nice': 'Maybe?', 'name': "Bob"},
-    ...     specific={'animals': {'name': 'Fido'}},
-    >>> )
-    >>> useless_database = {
-    ...     'animals': {'id': [], 'name': []},
-    ...     'people': {'id': [], 'name': []}
-    >>> }
-    >>> translator = Translator(useless_database, default_translations=default_translations,
-    ...                         fmt='{id}:{name}[, nice={is_nice}]')
-    >>> data = {'animals': [0], 'people': [0]}
-    >>> for key, translated_table in translator.translate(data).items():
-    >>>     print(f'Translations for {repr(key)}:')
-    >>>     for translated_id in translated_table:
-    >>>         print(f'    {repr(translated_id)}')
-            Translations for 'animals':
-                '0:Fido'
-            Translations for 'people':
-                '0:Bob'
-
-    Since we didn't give an explicit `default_fmt`, the regular `fmt` is used instead. Formats can be plain strings,
-    in which case tranlation will never explicitly fail unless the name itself fails to map and
-    :attr:`.Mapper.unmapped_values_action` is set to :attr:`.ActionLevel.RAISE`.
+        >>> default_fmt_placeholders = dict(
+        ...     default={'is_nice': 'Maybe?', 'name': "Bob"},
+        ...     specific={'animals': {'name': 'Fido'}},
+        >>> )
+        >>> useless_database = {
+        ...     'animals': {'id': [], 'name': []},
+        ...     'people': {'id': [], 'name': []}
+        >>> }
+        >>> translator = Translator(useless_database, default_fmt_placeholders=default_fmt_placeholders,
+        ...                         fmt='{id}:{name}[, nice={is_nice}]')
+        >>> data = {'animals': [0], 'people': [0]}
+        >>> for key, translated_table in translator.translate(data).items():
+        >>>     print(f'Translations for {repr(key)}:')
+        >>>     for translated_id in translated_table:
+        >>>         print(f'    {repr(translated_id)}')
+        Translations for 'animals':
+            '0:Fido, nice=Maybe?'
+        Translations for 'people':
+            '0:Bob, nice=Maybe?'
 
+        Since we didn't give an explicit `default_fmt_placeholders`, the regular `fmt` is used instead. Formats can be
+        plain strings, in which case tranlation will never explicitly fail unless the name itself fails to map and
+        :attr:`.Mapper.unmapped_values_action` is set to :attr:`.ActionLevel.RAISE`.
     """
 
+    def __init__(
+        self,
+        fetcher: FetcherTypes = None,
+        fmt: FormatType = "{id}:{name}",
+        mapper: Mapper[NameType, SourceType, None] = None,
+        default_fmt: FormatType = None,
+        default_fmt_placeholders: MakeType = None,
+        allow_name_inheritance: bool = True,
+    ) -> None:
+        self._fmt = fmt if isinstance(fmt, Format) else Format(fmt)
+        self._default_fmt_placeholders, self._default_fmt = _handle_default(
+            self._fmt, default_fmt, default_fmt_placeholders
+        )
+
+        self._cached_tmap: TranslationMap = TranslationMap({})
+        self._fetcher: Fetcher[SourceType, IdType]
+        if fetcher is None:
+            from rics.translation.testing import TestFetcher, TestMapper
+
+            self._fetcher = TestFetcher([])  # No explicit sources
+            if mapper:  # pragma: no cover
+                warnings.warn(
+                    f"Mapper instance {mapper} given; consider creating a TestFetcher([sources..])-instance manually.",
+                    UserWarning,
+                )
+            else:
+                mapper = TestMapper()  # type: ignore
+            warnings.warn("No fetcher given. Translation data will be automatically generated.", UserWarning)
+        elif isinstance(fetcher, Fetcher):
+            self._fetcher = fetcher
+        elif isinstance(fetcher, dict):
+            self._cached_tmap = self._to_translation_map(
+                {source: PlaceholderTranslations.make(source, pht) for source, pht in fetcher.items()}
+            )
+        elif isinstance(fetcher, TranslationMap):
+            tmap = fetcher.copy()
+            tmap.fmt = self._fmt
+            tmap.default_fmt = self._default_fmt
+            tmap.default_fmt_placeholders = self._default_fmt_placeholders  # type: ignore
+            self._cached_tmap = tmap
+        else:
+            raise TypeError(type(fetcher))  # pragma: no cover
+
+        self._mapper: Mapper = mapper or Mapper()
+
+        # Misc config
+        self._allow_name_inheritance = allow_name_inheritance
+
     @classmethod
     def from_config(
         cls,
         path: PathLikeType,
         extra_fetchers: Iterable[str] = (),
-        /,
-        fetcher_factory: factory.FetcherFactory = factory.default_fetcher_factory,
-        mapper_factory: factory.MapperFactory = factory.default_mapper_factory,
     ) -> "Translator":
-        """See :class:`.TranslatorFactory`."""
-        return factory.TranslatorFactory(path, extra_fetchers, fetcher_factory, mapper_factory).create()
+        """Create a ``Translator`` from TOML inputs.
 
-    from_config.__doc__ = factory.TranslatorFactory.__doc__
+        Args:
+            path: Path to a TOML file, or a pre-parsed dict.
+            extra_fetchers: Path to TOML files defining additional fetchers. Useful for fetching from multiple sources
+                or kinds of sources, for example locally stored files in conjunction with one or more databases. The
+                fetchers are ranked by input order, with the fetcher defined in `path` being given the highest priority
+                (rank 0).
 
-    def __init__(
-        self,
-        fetcher: Union[
-            Fetcher[SourceType, IdType],
-            TranslationMap[NameType, SourceType, IdType],
-            SourcePlaceholderTranslations[SourceType],
-            Dict[SourceType, PlaceholderTranslations.MakeTypes],
-        ],
-        fmt: FormatType = "{id}:{name}",
-        mapper: Mapper[NameType, SourceType, None] = None,
-        default_fmt: FormatType = None,
-        default_translations: MakeType = None,
-    ) -> None:
-        self._fmt = fmt if isinstance(fmt, Format) else Format(fmt)
-        self._mapper = mapper or Mapper()
-        self._default, self._default_fmt = _handle_default(self._fmt, default_fmt, default_translations)
+        Returns:
+            A ``Translator`` instance.
 
-        self._cached_tmap: TranslationMap
-        if isinstance(fetcher, Fetcher):
-            self._fetcher: Fetcher = fetcher
-            self._cached_tmap = TranslationMap({})
-        else:  # pragma: no cover
-            self._cached_tmap = (
-                self._to_translation_map(
-                    {source: PlaceholderTranslations.make(source, pht) for source, pht in fetcher.items()}
-                )
-                if isinstance(fetcher, dict)
-                else fetcher
-            )
+        See Also:
+            The :ref:`translator-config` page.
+        """
+        return factory.TranslatorFactory(path, extra_fetchers).create()
 
     def copy(self, share_fetcher: bool = True, **overrides: Any) -> "Translator":
         """Make a copy of this ``Translator``.
@@ -177,7 +217,7 @@ class Translator(Generic[Translatable, NameType, SourceType, IdType]):
             NotImplementedError: If ``share_fetcher=False``.
         """
         if not share_fetcher:
-            raise NotImplementedError("Fetcher clone not implemented.")
+            raise NotImplementedError("Fetcher cloning not implemented.")
 
         kwargs: Dict[str, Any] = {
             "fmt": self._fmt,
@@ -188,66 +228,78 @@ class Translator(Generic[Translatable, NameType, SourceType, IdType]):
         if "mapper" not in kwargs:  # pragma: no cover
             kwargs["mapper"] = self.mapper.copy()
 
-        if "fetcher" not in kwargs:  # pragma: no cover
-            kwargs["fetcher"] = self.fetcher if self.online else self._cached_tmap.copy()  # type: ignore
+        if "default_fmt_placeholders" not in kwargs:
+            kwargs["default_fmt_placeholders"] = self._default_fmt_placeholders
 
-        if "default_translations" not in kwargs:  # pragma: no cover
-            kwargs["default_translations"] = self._default
+        if "fetcher" not in kwargs:
+            kwargs["fetcher"] = self.fetcher if self.online else self._cached_tmap.copy()
 
         return Translator(**kwargs)
 
     def translate(
         self,
         translatable: Translatable,
-        names: Names = None,
+        names: NameTypes = None,
         ignore_names: Names = None,
         inplace: bool = False,
         override_function: ExtendedOverrideFunction = None,
         maximal_untranslated_fraction: float = 1.0,
         reverse: bool = False,
+        attribute: str = None,
     ) -> Optional[Translatable]:
         """Translate IDs to human-readable strings.
 
         Args:
             translatable: A data structure to translate.
-            names: Explicit names to translate. Will try to derive form `translatable` if not given. May also be a
-                predicate which indicates (returns ``True`` for) derived names to keep.
-            ignore_names: Names **not** to translate. Always precedence over `names`, both explicit and derived. May
-                also be a predicate which indicates (returns ``True`` for) names to ignore.
-            inplace: If ``True``, translation is performed in-place and this function returns ``None``.
-            override_function: A callable with inputs (value, candidates, ids) that returns either ``None``, the source
-                to use, or a split mapping ``{source: [ids_for_source..]}`` which forces IDs to be fetched from
-                different sources in spite of being labelled with the same name. Used only for name-to-source mapping.
+            names: Explicit names to translate. Derive from `translatable` if ``None``.
+            ignore_names: Names **not** to translate, or a predicate ``(str) -> bool``.
+            inplace: If ``True``, translate in-place and return ``None``.
+            override_function: A callable ``(name, fetcher.sources, ids) -> ...`` returning one of
+
+                * ``None`` (use regular mapping logic)
+                * a ``source`` to use, or
+                * a split mapping ``{source: [ids_for_source..]}``. This forces IDs to be fetched from
+                  different sources in spite of being labelled with the same name.
+
             maximal_untranslated_fraction: The maximum fraction of IDs for which translation may fail before an error is
                 raised. 1=disabled. Ignored in `reverse` mode.
-            reverse: If ``True``, perform reverse translations back to IDs instead. Offline mode only.
+            reverse: If ``True``, perform translations back to IDs. Offline mode only.
+            attribute: If given, translate ``translatable.attribute`` instead. If ``inplace=False``, the translated
+                attribute will be assigned to `translatable` using
+                ``setattr(translatable, attribute, <translated-attribute>)``.
 
         Returns:
-            A copy of `translatable` with IDs replaced by translations if ``inplace=False``, otherwise ``None``.
+            A copy of translated copy of `translatable` if ``inplace=False``, otherwise ``None``.
 
         Raises:
-            UntranslatableTypeError: If `translatable` is not translatable using any standard IOs.
+            UntranslatableTypeError: If ``type(translatable)`` cannot be translated.
             AttributeError: If `names` are not given and cannot be derived from `translatable`.
             MappingError: If required (explicitly given) names fail to map to a source.
             ValueError: If `maximal_untranslated_fraction` is not a valid fraction.
             TooManyFailedTranslationsError: If translation fails for more than `maximal_untranslated_fraction` of IDs.
             ConnectionStatusError: If ``reverse=True`` while the ``Translator`` is online.
-            UnknownSourceError: If `override_function` returns a source which is not known to the ``Translator``.
+            UnknownSourceError: If `override_function` returns a source which is not known.
 
         See Also:
             The :meth:`.Mapper.apply` function, which performs both placeholder and name-to-source mapping.
-        """
+        """  # noqa: DAR101 darglint is bugged here
         if self.online and reverse:  # pragma: no cover
             raise ConnectionStatusError("Reverse translation cannot be performed online.")
 
         if not (0.0 <= maximal_untranslated_fraction <= 1):  # pragma: no cover
             raise ValueError(f"Argument {maximal_untranslated_fraction=} is not a valid fraction")
 
+        if attribute:
+            obj, translatable = translatable, getattr(translatable, attribute)
+        else:
+            obj = None
+
         translation_map, names_to_translate = self._get_updated_tmap(
             translatable,
             names,
             ignore_names=ignore_names,
             override_function=override_function,
+            parent=obj if (obj is not None and self._allow_name_inheritance) else None,
         )
         if not translation_map:
             return None if inplace else translatable  # pragma: no cover
@@ -258,19 +310,21 @@ class Translator(Generic[Translatable, NameType, SourceType, IdType]):
                 translatable, names_to_translate, translation_map, translatable_io, maximal_untranslated_fraction
             )
 
-        if reverse:
-            translation_map.reverse_mode = True
-            try:
-                return translatable_io.insert(
-                    translatable, names=names_to_translate, tmap=translation_map, copy=not inplace
-                )
-            finally:
-                translation_map.reverse_mode = False
+        translation_map.reverse_mode = reverse
+        try:
+            ans = translatable_io.insert(translatable, names=names_to_translate, tmap=translation_map, copy=not inplace)
+        finally:
+            translation_map.reverse_mode = False
 
-        else:
-            return translatable_io.insert(
-                translatable, names=names_to_translate, tmap=translation_map, copy=not inplace
-            )
+        if attribute and not inplace and ans is not None:
+            setattr(obj, attribute, ans)
+            # Hacky special handling for eg pandas.Index
+            if hasattr(ans, "name") and hasattr(translatable, "name"):  # pragma: no cover
+                # Mypy doesn't understand hasattr?
+                ans.name = translatable.name  # type: ignore
+            return obj
+
+        return ans
 
     def __call__(
         self,
@@ -284,10 +338,10 @@ class Translator(Generic[Translatable, NameType, SourceType, IdType]):
 
     __call__.__doc__ = translate.__doc__
 
-    def map_to_sources(
+    def map(  # noqa: A003
         self,
         translatable: Translatable,
-        names: Names = None,
+        names: NameTypes = None,
         ignore_names: Names = None,
         override_function: ExtendedOverrideFunction = None,
     ) -> Optional[DirectionalMapping]:
@@ -295,23 +349,34 @@ class Translator(Generic[Translatable, NameType, SourceType, IdType]):
 
         Args:
             translatable: A data structure to map names for.
-            names: Explicit names to translate. Will try to derive form `translatable` if not given. May also be a
-                predicate which indicates (returns ``True`` for) derived names to keep.
-            ignore_names: Names **not** to translate. Always precedence over `names`, both explicit and derived. May
-                also be a predicate which indicates (returns ``True`` for) names to ignore.
-            override_function: A callable with inputs (value, candidates, ids) that returns either ``None``, the source
-                to use, or a split mapping ``{source: [ids_for_source..]}`` which forces IDs to be fetched from
-                different sources in spite of being labelled with the same name. Used only for name-to-source mapping.
+            names: Explicit names to translate. Derive from `translatable` if ``None``.
+            ignore_names: Names **not** to translate, or a predicate ``(str) -> bool``.
+            override_function: A callable ``(name, fetcher.sources, ids) -> ...`` returning one of
+
+                * ``None`` (use regular mapping logic)
+                * a ``source`` to use, or
+                * a split mapping ``{source: [ids_for_source..]}``. This forces IDs to be fetched from
+                  different sources in spite of being labelled with the same name.
 
         Returns:
-            A mapping of names to translation sources. Returns ``None`` if mapping failed but success was not required.
+            A mapping of names to translation sources. Returns ``None`` if mapping failed.
 
         Raises:
             AttributeError: If `names` are not given and cannot be derived from `translatable`.
             MappingError: If required (explicitly given) names fail to map to a source.
-            UnknownSourceError: If `override_function` returns a source which is not known to the ``Translator``.
+            UnknownSourceError: If `override_function` returns a source which is not known.
         """
-        names_to_translate = self._resolve_names(translatable, names, ignore_names)
+        return self._map_inner(translatable, names, ignore_names=ignore_names, override_function=override_function)
+
+    def _map_inner(
+        self,
+        translatable: Translatable,
+        names: NameTypes = None,
+        ignore_names: Names = None,
+        override_function: ExtendedOverrideFunction = None,
+        parent: Translatable = None,
+    ) -> Optional[DirectionalMapping]:
+        names_to_translate = self._resolve_names(translatable, names, ignore_names, parent)
         sources = self.fetcher.sources if self.online else self._cached_tmap.sources
 
         def func(value: NameType, candidates: Set[SourceType], _: None) -> Optional[SourceType]:
@@ -327,23 +392,24 @@ class Translator(Generic[Translatable, NameType, SourceType, IdType]):
                 return res
 
         if override_function is None:
-            name_to_source = self.mapper(names_to_translate, sources)
+            name_to_source = self.mapper.apply(names_to_translate, sources)
         else:
             try:
-                name_to_source = self.mapper(names_to_translate, sources, override_function=func)
+                name_to_source = self.mapper.apply(names_to_translate, sources, override_function=func)
             except UserMappingError as e:
                 raise UnknownSourceError(e.value, e.candidates) from e
 
-        # Fail if any of the explicitly given (ie literal, not predicate) names fail to map to a source.
-        if isinstance(names, (str, Iterable)):
-            required = set(self._dont_ruin_string(names))
+        # Fail if any of the explicitly given (i.e. literal, not predicate) names fail to map to a source.
+        if isinstance(names, (int, str, Iterable)):
+            required = set(as_list(names))
             unmapped = required.difference(name_to_source.left)
             if unmapped:
                 raise MappingError(f"Required names {unmapped} not mapped with {sources=} and {ignore_names=}.")
 
         if not name_to_source.left:
-            msg = f"None of {names=} could not be mapped with {sources=}. Translation aborted"
-            warnings.warn(msg)
+            msg = f"Translation aborted since none of {names=} could be mapped with {sources=}"
+            warnings.warn(msg, MappingWarning)
+            LOGGER.warning(msg)
             return None
 
         return name_to_source
@@ -358,14 +424,15 @@ class Translator(Generic[Translatable, NameType, SourceType, IdType]):
 
         Args:
             translatable: A data structure to translate.
-            name_to_source: Mappings of names in `translatable` to translation sources known the fetcher.
-            data_structure_io: Data Structure IO class used to extract IDs from `translatable`. Derive if ``None``.
+            name_to_source: Mappings of names in `translatable` to :attr:`~.Fetcher.sources` as they are known to the
+                :attr:`fetcher`.
+            data_structure_io: Static namespace used to extract IDs from `translatable`.
 
         Returns:
-            A :class:`.TranslationMap`.
+            A ``TranslationMap``.
 
         Raises:
-            ConnectionStatusError: If disconnected from the fetcher, ie not :attr:`online`.
+            ConnectionStatusError: If disconnected from the fetcher, i.e. not :attr:`online`.
         """
         ids_to_fetch = self._get_ids_to_fetch(
             name_to_source, translatable, data_structure_io or resolve_io(translatable)
@@ -435,10 +502,8 @@ class Translator(Generic[Translatable, NameType, SourceType, IdType]):
 
         Args:
             translatable: Data from which IDs to fetch will be extracted. Fetch all IDs if ``None``.
-            names: Explicit names to translate. Will try to derive form `translatable` if not given. May also be a
-                predicate which indicates (returns ``True`` for) derived names to keep.
-            ignore_names: Names **not** to translate. Always precedence over `names`, both explicit and derived. May
-                also be a predicate which indicates (returns ``True`` for) names to ignore.
+            names: Explicit names to translate. Derive from `translatable` if ``None``.
+            ignore_names: Names **not** to translate, or a predicate ``(str) -> bool``.
             delete_fetcher: If ``True``, invoke :meth:`.Fetcher.close` and delete the fetcher after retrieving data. The
                 ``Translator`` will still function, but new data cannot be retrieved.
             path: If given, serialize the ``Translator`` to disk after retrieving data.
@@ -447,14 +512,12 @@ class Translator(Generic[Translatable, NameType, SourceType, IdType]):
             Self, for chained assignment.
 
         Raises:
-            ForbiddenOperationError: If the fetcher does not permit the FETCH_ALL operation (only when `translatable` is
-                ``None``).
-            MappingError: If a `translatable` is given, but no names to translate could be extracted.
+            ForbiddenOperationError: If :meth:`.Fetcher.fetch_all` is disabled and ``translatable=None``.
+            MappingError: If :meth:`map` fails (only when `translatable` is given).
 
         Notes:
-            The ``Translator`` is guaranteed to be serializable once offline. Fetchers often aren't as they require
-            things like database connections to function. Serializability can be tested using the
-            :meth:`rics.utility.misc.serializable` method.
+            The ``Translator`` is guaranteed to be :meth:`~rics.utility.misc.serializable` once offline. Fetchers often
+            aren't as they require things like database connections to function.
 
         See Also:
             The :meth:`Translator.restore` method.
@@ -493,10 +556,11 @@ class Translator(Generic[Translatable, NameType, SourceType, IdType]):
     def _get_updated_tmap(
         self,
         translatable: Translatable,
-        names: Names = None,
+        names: NameTypes = None,
         ignore_names: Names = None,
         override_function: ExtendedOverrideFunction = None,
         force_fetch: bool = False,
+        parent: Translatable = None,
     ) -> Tuple[Optional[TranslationMap], List[NameType]]:
         """Get an updated translation map.  # noqa
 
@@ -511,7 +575,7 @@ class Translator(Generic[Translatable, NameType, SourceType, IdType]):
         """
         translatable_io = resolve_io(translatable)  # Fail fast if untranslatable type
 
-        name_to_source = self.map_to_sources(translatable, names, ignore_names, override_function)
+        name_to_source = self._map_inner(translatable, names, ignore_names, override_function, parent)
         if name_to_source is None:
             # Nothing to translate.
             return None, []  # pragma: no cover
@@ -559,8 +623,8 @@ class Translator(Generic[Translatable, NameType, SourceType, IdType]):
         return TranslationMap(
             source_translations,
             fmt=self._fmt,
-            default=self._default,
             default_fmt=self._default_fmt,
+            default_fmt_placeholders=self._default_fmt_placeholders,
         )
 
     @staticmethod
@@ -603,24 +667,25 @@ class Translator(Generic[Translatable, NameType, SourceType, IdType]):
     def _resolve_names(
         self,
         translatable: Translatable,
-        names: Optional[Names],
-        ignored_names: Optional[Names],
+        names: NameTypes = None,
+        ignored_names: Names = None,
+        parent: Translatable = None,  # This isn't correct; should be different typevars.
     ) -> List[NameType]:
-
-        found_names: NameTypes
-        if names is None or callable(names):
-            found_names = self._extract_from_attribute(translatable)
-            if callable(names):
-                keep_predicate: NamesPredicate = names
-                found_names = list(filter(keep_predicate, found_names))
+        if names is None:
+            if parent is None:
+                names = self._extract_from_attribute(translatable)
+            else:
+                try:
+                    names = self._extract_from_attribute(translatable)
+                except AttributeError:
+                    names = self._extract_from_attribute(parent)
+                    LOGGER.debug(
+                        f"Using {names=} from parent of type {tname(parent)} for child of type {tname(translatable)}"
+                    )
         else:
-            found_names = self._dont_ruin_string(names)
-
-        names_to_translate: List[NameType] = self._resolve_names_inner(
-            names=found_names,
-            ignored_names=ignored_names if callable(ignored_names) else set(self._dont_ruin_string(ignored_names)),
-        )
-        return names_to_translate
+            names = as_list(names)
+        ignored_names = ignored_names if callable(ignored_names) else set(as_list(ignored_names))
+        return self._resolve_names_inner(names, ignored_names)
 
     @classmethod
     def _extract_from_attribute(cls, translatable: Translatable) -> List[NameType]:
@@ -634,10 +699,12 @@ class Translator(Generic[Translatable, NameType, SourceType, IdType]):
                 if attr is None:
                     no_use_keys = True
                 else:
-                    return cls._dont_ruin_string(attr() if callable(attr) else attr)
+                    return as_list(attr() if callable(attr) else attr)
 
         raise AttributeError(
-            "Must pass 'names' since type " f"'{type(translatable)}' has none of {_NAME_ATTRIBUTES} as and attribute."
+            "Must pass 'names' since no valid name could be found for data of type "
+            f"'{tname(translatable)}'."
+            f" Attributes checked: {_NAME_ATTRIBUTES}."
         )
 
     @classmethod
@@ -650,16 +717,6 @@ class Translator(Generic[Translatable, NameType, SourceType, IdType]):
             warnings.warn(f"No names left to translate. Ignored names: {ignored_names}, explicit names: {names}.")
         return names_to_translate
 
-    @classmethod
-    def _dont_ruin_string(cls, arg: Optional[NameTypes]) -> List[NameType]:
-        if arg is None:
-            return []
-        if not isinstance(arg, str) and isinstance(arg, Iterable):
-            return list(arg)
-
-        # https://github.com/python/mypy/issues/10835
-        return [arg]  # type: ignore
-
 
 class _IgnoredNamesPredicate(Generic[NameType]):
     def __init__(self, ignored_names: Union[NamesPredicate, Set[NameType]]) -> None:
@@ -672,17 +729,17 @@ class _IgnoredNamesPredicate(Generic[NameType]):
 def _handle_default(
     fmt: Format,
     default_fmt: Optional[FormatType],
-    default_translations: Optional[MakeType],
+    default_fmt_placeholders: Optional[MakeType],
 ) -> Tuple[Optional[InheritedKeysDict], Optional[Format]]:  # pragma: no cover
-    if default_fmt is None and default_translations is None:
+    if default_fmt is None and default_fmt_placeholders is None:
         return None, None
 
     dt: Optional[InheritedKeysDict] = None
 
-    if isinstance(default_translations, InheritedKeysDict):
-        dt = default_translations
-    elif isinstance(default_translations, dict):
-        dt = InheritedKeysDict.make(default_translations)
+    if isinstance(default_fmt_placeholders, InheritedKeysDict):
+        dt = default_fmt_placeholders
+    elif isinstance(default_fmt_placeholders, dict):
+        dt = InheritedKeysDict.make(default_fmt_placeholders)
 
     dfmt: Optional[Format]
     if default_fmt is None:
@@ -699,13 +756,4 @@ def _handle_default(
     if dfmt is not None:
         dt = dt or InheritedKeysDict()
 
-    if dfmt is not None:
-        extra = set(dfmt.placeholders).difference(fmt.placeholders)
-        extra.discard(ID)
-        if extra:
-            raise ValueError(
-                f"The given fallback translation format {repr(default_fmt)} uses placeholders "
-                f"{sorted(extra)} which are not in the main format, which is not supported."
-            )
-
     return dt, dfmt
